# Impute genetically regulated gene expression for CENTER-TBI using PrediXcan

This repository contains all scripts necessary to run the impute genetically
regulated gene expression (GREx) using the 
[PrediXcan](https://github.com/hakyimlab/MetaXcan) methodology for 
[CENTER-TBI](https://www.center-tbi.eu/) imputed whole genomes data.

[1] Gamazon ER†, Wheeler HE, Shah KP, Mozaffari SV, Aquino-Michaels K, Carroll RJ, Eyler AE, Denny JC,
Nicolae DL, Cox NJ, Im HK. (2015) *A gene-based association method for mapping traits using reference transcriptome data.*
Nat Genet. doi:10.1038/ng.3367.

[2] Barbeira, A., Shah, K. P., Torres, J. M., Wheeler, H. E., Torstenson, E. S., Edwards, T., ... & Im, H. K. (2016). *MetaXcan: summary statistics based gene-level association method infers accurate PrediXcan results.* BioRxiv, 045260.

The pipeline itself is implemented using [snakemake](https://snakemake.readthedocs.io/en/stable/) and
[singularity](https://sylabs.io/) containers to guarantee reproducibility.



## Dependencies

1. [`Linux` system](https://ubuntu.com/download/desktop)
2. [`git`](https://git-scm.com/book/en/v2/Getting-Started-Installing-Git)
3. [`singularity`](https://sylabs.io/guides/3.5/user-guide/quick_start.html#quick-installation-steps) container software (tested on 3.5.0)
4. *optionally:* [Python 3](https://www.python.org/) and [snakemake](https://github.com/snakemake/snakemake) 

To access the imputed genotypes, access to the 
[FIMM](https://www.fimm.fi/) GCS bucket 
`fimm-horizon-outgoing-data` is necessary (requires a FIMM user account).

It is recommended to run the workflow on a cluster system, 
since execution time on a desktop machine may take several hours.
An example [slurm](https://slurm.schedmd.com/documentation.html)
cluster [profile](https://snakemake.readthedocs.io/en/stable/executing/cli.html#profiles) is saved in `config/snakemake/mrc-bsu-cluster` 
for reference.



## Execution

### Local execution

1.  Clone this repository and change the working directory to the newly 
    created folder
    ```
    git clone https://git.center-tbi.eu/kunzmann/impute-gene-expression.git
    cd impute-gene-expression
    ```
    Make sure the ckeck out the exact version of the pipeline you want to run,
    either by comit hash, or an available tag, e.g. via
    ```
    git checkout v0.1.0
    ```
2.  Download the container image specified at the to of the `Snakefile`
    (singularity: ...) manually via, e.g. (make sure to adjust to the exact specification!)
    ```
    singularity pull library://kkmann/default/center-grex-imputation:[tag]
    ```
    where `[tag]` is the desired container tag or hash (see Snakefile to make
    sure that you download the exact right version).
    This will download the container from the sylab cloud and store it as
    `center-grex-imputation_[tag].sif`.
3.  Authenticate with your FIMM account
    ```
    singularity shell -H $PWD [container-name].sif
    [container-name].sif> gcloud auth login
    ```
    Here, the `-H $PWD` flag ensures that singularity does not mount the users
    home directory but uses the working directory instead.
    Follow the on-screen instructions to authenticate in your browser, 
    then leave the container
    ```
    [container-name].sif> exit
    ```
    This should have creates a hidden folder `.config/gcloud` with authentification 
    details in your working directory.
4.  Adjust tissues, data date, and target cohort in `config/parameters.yaml`
4.  Run the pipeline
    ```
    singularity exec -H $PWD -j 1 [container-name].sif snakemake all
    ```
    Here `-j 1` specifies the maximal number of parallel jobs.
    Increase this on more powerful machines but bear in mind that roughly 16Gb
    of RAM per job are required to avoid out of memory issues.
    An output folder is created with intermediate files, a mapping report, 
    and the imputed GREx levels per tissue in `output/imputed-grex`.

### Cluster execution

1.  Same as the first step in 'Local execution'.
2.  Make sure that `Python 3` is available and `snakemake` installed 
    (e.g. load Python via modules and install snakemake into a virtual environment)
3.  Configure snakemake for your execution environment and store the profile in, 
    e.g., `config/my-cluster`.
    It is highly recommended to use the `-H $PWD` flag to make sure that there
    is no interference with configuration files int he users home directory.
3.  Run
    ```
    snakemake --profile config/my-cluster container
    ```
    to download the correct container image automatically.
    This will create a file `[container-hash].simg` in the working folder.
4.  Authenticate with your FIMM account as in 'Local execution', point 3., 
    with a shell in the downloaded `[container-hash].simg`
5.  Adjust tissues, data date, and target cohort in `config/parameters.yaml`
6.  Run the distributed pipeline
    ```
    snakemake --profile config/snakemake/my-cluster all
    ```


## Logo

CC-BY 4.0, Ali Zifan
