#!/usr/bin/env Rscript

options(tidyverse.quite = TRUE)
suppressPackageStartupMessages(library(tidyverse, warn.conflicts = FALSE))
library(glue, warn.conflicts = FALSE)
library(DBI)

tissues  <- yaml::read_yaml("config/parameters.yml")$tissues

tbl_weights <- map(
        tissues,
        function(tissue) {
            con <- dbConnect(
                RSQLite::SQLite(),
                glue("output/weights/en_{tissue}.db")
            )
            res <- dbReadTable(con, "weights") %>%
                as_tibble() %>%
                mutate(tissue = tissue) %>%
                select(tissue, everything())
            dbDisconnect(con)
            return(res)
        }
    ) %>%
    bind_rows() %>%
    separate(
        varID,
        into = c("chr", "position", "allele1", "allele2", "dummy"),
        sep = "_",
        remove = FALSE
    ) %>% {
        assertthat::assert_that(
            all((.$allele1 == .$ref_allele) & (.$allele2 == .$eff_allele))
        )
        .
    } %>%
    select(
        chr, position, rsid, varID, allele1, allele2
    ) %>%
    rename(
        gtex_id  = varID
    ) %>%
    mutate(
        position = as.integer(position)
    ) %>%
    distinct()

write_csv(
    tbl_weights,
    "output/model-variants-lookup-table.csv.gz"
)
